## Cut videos oh yes

This project is gruit of hours trying to cut videos with shitty ffmpeg.


limitations:
- can't cut segments shorter than 3 seconds for now


todo:
- remove all the temporary files
- add a cut_video(..., encode=True) for cuts shorter than 3 seconds
